@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 2002 Jonathan Blandford <jrb@redhat.com>
+ * Copyright © 2002 Jonathan Blandford <jrb@redhat.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 3 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +20,14 @@
 #ifndef SKEY_POPUP_H
 #define SKEY_POPUP_H
 
-#include "terminal-screen.h"
 #include <gtk/gtk.h>
 
+#include "terminal-screen.h"
+
 G_BEGIN_DECLS
 
-void terminal_skey_do_popup (TerminalScreen *screen,
-			     GtkWindow      *transient_parent,
+void terminal_skey_do_popup (GtkWindow *window,
+                             TerminalScreen *screen,
 			     const gchar    *skey_match);
 
 G_END_DECLS
