@@ -1,10 +1,10 @@
 /*
  * Copyright © 2001 Havoc Pennington
- * Copyright © 2007, 2008 Christian Persch
+ * Copyright © 2007, 2008, 2010 Christian Persch
  *
  * Gnome-terminal is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * Gnome-terminal is distributed in the hope that it will be useful,
@@ -39,11 +39,7 @@
 #include "terminal-screen-container.h"
 #include "terminal-util.h"
 #include "terminal-window.h"
-
-#if GTK_CHECK_VERSION (2, 18, 0)
 #include "terminal-info-bar.h"
-#define USE_INFOBARS
-#endif
 
 #include "eggshell.h"
 
@@ -140,7 +136,6 @@ static char* terminal_screen_check_match       (TerminalScreen            *scree
                                                 int                   column,
                                                 int                   row,
                                                 int                  *flavor);
-static void  terminal_screen_skey_match_remove (TerminalScreen            *screen);
 
 static guint signals[LAST_SIGNAL];
 
@@ -170,17 +165,22 @@ static const TerminalRegexPattern url_regex_patterns[] = {
   { "news:[[:alnum:]\\Q^_{|}~!\"#$%&'()*+,./;:=?`\\E]+", FLAVOR_AS_IS, G_REGEX_CASELESS  },
 };
 
+static GRegex **url_regexes;
+static TerminalURLFlavour *url_regex_flavors;
+static guint n_url_regexes;
+
+#ifdef ENABLE_SKEY
 static const TerminalRegexPattern skey_regex_patterns[] = {
   { "s/key [[:digit:]]* [-[:alnum:]]*",         FLAVOR_AS_IS },
   { "otp-[a-z0-9]* [[:digit:]]* [-[:alnum:]]*", FLAVOR_AS_IS },
 };
 
-static GRegex **url_regexes;
-static TerminalURLFlavour *url_regex_flavors;
-static guint n_url_regexes;
 static GRegex **skey_regexes;
 static guint n_skey_regexes;
 
+static void  terminal_screen_skey_match_remove (TerminalScreen            *screen);
+#endif /* ENABLE_SKEY */
+
 G_DEFINE_TYPE (TerminalScreen, terminal_screen, VTE_TYPE_TERMINAL)
 
 static char *
@@ -223,7 +223,7 @@ cwd_of_pid (int pid)
               if (chdir (cwd_file) == 0)
                 {
                   working_dir = g_get_current_dir ();
-                  chdir (cwd);
+                  (void) chdir (cwd);
                 }
               g_free (cwd);
             }
@@ -273,11 +273,7 @@ terminal_screen_get_window (TerminalScreen *screen)
   GtkWidget *toplevel;
 
   toplevel = gtk_widget_get_toplevel (widget);
-#if GTK_CHECK_VERSION (2, 18, 0)
   if (!gtk_widget_is_toplevel (toplevel))
-#else
-  if (!GTK_WIDGET_TOPLEVEL (toplevel))
-#endif
     return NULL;
 
   return TERMINAL_WINDOW (toplevel);
@@ -605,8 +601,6 @@ terminal_screen_class_init (TerminalScreenClass *klass)
   n_url_regexes = G_N_ELEMENTS (url_regex_patterns);
   url_regexes = g_new0 (GRegex*, n_url_regexes);
   url_regex_flavors = g_new0 (TerminalURLFlavour, n_url_regexes);
-  n_skey_regexes = G_N_ELEMENTS (skey_regex_patterns);
-  skey_regexes = g_new0 (GRegex*, n_skey_regexes);
 
   for (i = 0; i < n_url_regexes; ++i)
     {
@@ -624,6 +618,10 @@ terminal_screen_class_init (TerminalScreenClass *klass)
       url_regex_flavors[i] = url_regex_patterns[i].flavor;
     }
 
+#ifdef ENABLE_SKEY
+  n_skey_regexes = G_N_ELEMENTS (skey_regex_patterns);
+  skey_regexes = g_new0 (GRegex*, n_skey_regexes);
+
   for (i = 0; i < n_skey_regexes; ++i)
     {
       GError *error = NULL;
@@ -635,6 +633,7 @@ terminal_screen_class_init (TerminalScreenClass *klass)
           g_error_free (error);
         }
     }
+#endif /* ENABLE_SKEY */
 
   /* This fixes bug #329827 */
   app = terminal_app_get ();
@@ -974,6 +973,7 @@ terminal_screen_profile_notify_cb (TerminalProfile *profile,
       vte_terminal_set_scrollback_lines (vte_terminal, lines);
     }
 
+#ifdef ENABLE_SKEY
   if (!prop_name || prop_name == I_(TERMINAL_PROFILE_USE_SKEY))
     {
       if (terminal_profile_get_property_boolean (profile, TERMINAL_PROFILE_USE_SKEY))
@@ -997,6 +997,7 @@ terminal_screen_profile_notify_cb (TerminalProfile *profile,
           terminal_screen_skey_match_remove (screen);
         }
     }
+#endif /* ENABLE_SKEY */
 
   if (!prop_name ||
       prop_name == I_(TERMINAL_PROFILE_BACKGROUND_TYPE) ||
@@ -1353,11 +1354,7 @@ get_child_environment (TerminalScreen *screen,
 
   window = gtk_widget_get_toplevel (term);
   g_assert (window != NULL);
-#if GTK_CHECK_VERSION (2, 19, 3)
   g_assert (gtk_widget_is_toplevel (window));
-#else
-  g_assert (GTK_WIDGET_TOPLEVEL (window));
-#endif
 
   env_table = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
@@ -1408,8 +1405,6 @@ get_child_environment (TerminalScreen *screen,
   return (char **) g_ptr_array_free (retval, FALSE);
 }
 
-#ifdef USE_INFOBARS
-
 enum {
   RESPONSE_RELAUNCH,
   RESPONSE_EDIT_PROFILE
@@ -1443,8 +1438,6 @@ info_bar_response_cb (GtkWidget *info_bar,
   }
 }
 
-#endif /* USE_INFOBARS */
-
 static gboolean
 terminal_screen_launch_child_cb (TerminalScreen *screen)
 {
@@ -1489,7 +1482,6 @@ terminal_screen_launch_child_cb (TerminalScreen *screen)
                                        NULL, NULL,
                                        &pid,
                                        &err)) {
-#ifdef USE_INFOBARS
     GtkWidget *info_bar;
 
     info_bar = terminal_info_bar_new (GTK_MESSAGE_ERROR,
@@ -1507,11 +1499,6 @@ terminal_screen_launch_child_cb (TerminalScreen *screen)
                         info_bar, FALSE, FALSE, 0);
     gtk_info_bar_set_default_response (GTK_INFO_BAR (info_bar), GTK_RESPONSE_CANCEL);
     gtk_widget_show (info_bar);
-#else
-    terminal_util_show_error_dialog (GTK_WINDOW (terminal_screen_get_window (screen)), NULL,
-                                     err,
-                                     "%s", _("There was an error creating the child process for this terminal"));
-#endif /* USE_INFOBARS */
 
     g_error_free (err);
     g_strfreev (env);
@@ -1601,7 +1588,6 @@ terminal_screen_button_press (GtkWidget      *widget,
                               GdkEventButton *event)
 {
   TerminalScreen *screen = TERMINAL_SCREEN (widget);
-  TerminalScreenPrivate *priv = screen->priv;
   gboolean (* button_press_event) (GtkWidget*, GdkEventButton*) =
     GTK_WIDGET_CLASS (terminal_screen_parent_class)->button_press_event;
   int char_width, char_height, row, col;
@@ -1628,8 +1614,10 @@ terminal_screen_button_press (GtkWidget      *widget,
     {
       gboolean handled = FALSE;
 
+#ifdef ENABLE_SKEY
       if (matched_flavor != FLAVOR_SKEY ||
-          terminal_profile_get_property_boolean (priv->profile, TERMINAL_PROFILE_USE_SKEY))
+          terminal_profile_get_property_boolean (screen->priv->profile, TERMINAL_PROFILE_USE_SKEY))
+#endif
         {
           g_signal_emit (screen, signals[MATCH_CLICKED], 0,
                          matched_string,
@@ -1878,7 +1866,6 @@ terminal_screen_child_exited (VteTerminal *terminal)
     case TERMINAL_EXIT_RESTART:
       terminal_screen_launch_child_on_idle (screen);
       break;
-#ifdef USE_INFOBARS
     case TERMINAL_EXIT_HOLD: {
       GtkWidget *info_bar;
       int status;
@@ -1907,7 +1894,6 @@ terminal_screen_child_exited (VteTerminal *terminal)
       gtk_widget_show (info_bar);
       break;
     }
-#endif /* USE_INFOBARS */
 
     default:
       break;
@@ -2220,6 +2206,7 @@ terminal_screen_get_cell_size (TerminalScreen *screen,
   *cell_height_pixels = vte_terminal_get_char_height (terminal);
 }
 
+#ifdef ENABLE_SKEY
 static void
 terminal_screen_skey_match_remove (TerminalScreen *screen)
 {
@@ -2241,6 +2228,7 @@ terminal_screen_skey_match_remove (TerminalScreen *screen)
       l = next;
     }
 }
+#endif /* ENABLE_SKEY */
 
 static char*
 terminal_screen_check_match (TerminalScreen *screen,
